@@ -9,7 +9,7 @@ import isort
 
 class Flake8IsortBase:
     name = 'flake8_isort'
-    version = '4.2.1'
+    version = '5.0.1'
     isort_unsorted = 'I001 isort found an import in the wrong position'
     no_config_msg = 'I002 no configuration found (.isort.cfg or [isort] in configs)'
     isort_blank_req = 'I003 isort expected 1 blank line in imports, found 0'
@@ -24,9 +24,9 @@ class Flake8IsortBase:
         self.filename = filename
         self.lines = lines
 
-    @classmethod
-    def add_options(cls, parser):
-        parser.add_option(
+    @staticmethod
+    def add_options(option_manager):
+        option_manager.add_option(
             '--isort-show-traceback',
             action='store_true',
             parse_from_config=True,
@@ -34,7 +34,7 @@ class Flake8IsortBase:
         )
 
     @classmethod
-    def parse_options(cls, options):
+    def parse_options(cls, option_manager, options, args):
         cls.stdin_display_name = options.stdin_display_name
         cls.show_traceback = options.isort_show_traceback
 
